/*
 * Project name:
     Tilt click Board Example
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
     20150325:
       - initial release (DM);
 * Description:
     This is a simple demonstration of the Tilt click Board usage.
 * Test configuration:
     MCU:             STM32F107VC
                      http://www.st.com/st-web-ui/static/active/en/resource/technical/document/reference_manual/CD00171190.pdf
     Dev. Board:      EasyMx PRO v7 for STM32
                      http://www.mikroe.com/eng/products/view/852/easymx-pro-v7-for-stm32/
     Oscillator:      HS-PLL 72.0000 MHz
     ext. modules:    Tilt click board
                      http://www.mikroe.com/click/tilt/
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/
 * NOTES:
     - Place Tilt click board at the mikroBUS socket 1 on the EasyMx Pro v7 board.
     - Put EasyTFT in its socket, turn on backlight using the SW11.3
  */

#include "resources.h"

// TFT module connections
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOE_ODR.B8;
sbit TFT_RS at GPIOE_ODR.B12;
sbit TFT_CS at GPIOE_ODR.B15;
sbit TFT_RD at GPIOE_ODR.B10;
sbit TFT_WR at GPIOE_ODR.B11;
sbit TFT_BLED at GPIOE_ODR.B9;
// End TFT module connections

sbit Tilt_V01 at GPIOA_IDR.B0;
sbit Tilt_V02 at GPIOD_IDR.B10;

void InitDisplay(){
  TFT_Init_ILI9341_8bit(320, 240);
  TFT_BLED = 1;
  TFT_Set_Pen(CL_WHITE, 1);
  TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
  TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);

  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_Black, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_LIne(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("Tilt Click", 125, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyMx PRO v7 for STM32", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
  TFT_Image_Jpeg(80, 55, arrows_default_jpg);             // Print arrows_default jpg picture on display
}

void main() {
  GPIO_Digital_Input(&GPIOA_IDR, _GPIO_PINMASK_0);        // Set GPIOA pin 0 as digital input
  GPIO_Digital_Input(&GPIOD_IDR, _GPIO_PINMASK_10);       // Set GPIOD pin 10 as digital input

  InitDisplay();                                          // Display initialization
  
  while(1){
    if ((Tilt_V02 == 1) & (Tilt_V01 == 0)){
      TFT_Image_Jpeg(80, 55, arrows_left_jpg);            // Print arrows_left jpg picture on display
    }
    
    if ((Tilt_V02 == 0) & (Tilt_V01 == 1)){
      TFT_Image_Jpeg(80, 55, arrows_right_jpg);           // Print arrows_right jpg picture on display
    }
    
    if ((Tilt_V02 == 1) & (Tilt_V01 == 1)){
      TFT_Image_Jpeg(80, 55, arrows_up_jpg);              // Print arrows_up jpg picture on display
    }
    
    if ((Tilt_V02 == 0) & (Tilt_V01 == 0)){
      TFT_Image_Jpeg(80, 55, arrows_down_jpg);            // Print arrows_down jpg picture on display
    }
  }
}